@@ -45,16 +45,11 @@ class DocManager(DocManagerBase):
         self.actor = []
         self.director = []
 
-    def apply_id_constraint(self, doc_types):
-        for doc_type in doc_types:
-            constraint = "CREATE CONSTRAINT ON (d:`{doc_type}`) ASSERT d._id IS UNIQUE".format(doc_type=doc_type)
-            self.graph.cypher.execute(constraint)
-
     def stop(self):
         """Stop the auto-commit thread."""
         self.auto_commit_interval = None
 
-    def upsert(self, doc):
+    def upsert(self, doc,namespace,timestamp):
         """Inserts a document into Neo4j."""
         doc_id = u(doc.pop("_id"))
         doc = self._formatter.format_document(doc)
@@ -89,23 +84,6 @@ class DocManager(DocManagerBase):
                         tx.run(self.creat_relationship(id, id_, type,program_id))
         tx.commit()
 
-    def bulk_upsert(self, docs, namespace, timestamp):
-        """Insert multiple documents into Neo4j."""
-        """Maximum chunk size is 1000. Transaction blocks won't have more than 1000 statements."""
-        metadata = {"_ts": timestamp}
-        tx = self.graph.cypher.begin()
-        for doc in docs:
-            index, doc_type = self._index_and_mapping(namespace)
-            doc_id = u(doc.pop("_id"))
-            doc = self._formatter.format_document(doc)
-            builder = NodesAndRelationshipsBuilder(doc, doc_type, doc_id, metadata)
-            self.apply_id_constraint(builder.doc_types)
-            for statement in builder.query_nodes.keys():
-                tx.append(statement, builder.query_nodes[statement])
-            for relationship in builder.relationships_query.keys():
-                tx.append(relationship, builder.relationships_query[relationship])
-        tx.commit()
-
 
     def commit(self):
         LOG.error("Commit")
